/**
 * Copyright 1998-2007, CHISEL Group, University of Victoria, Victoria, BC, Canada.
 * All rights reserved.
 */
package ca.uvic.csr.shrimp.ScriptingBean;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

import org.apache.bsf.BSFException;
import org.apache.bsf.BSFManager;

import ca.uvic.csr.shrimp.ShrimpProject.ShrimpProject;

/**
 * This represents the "interface" which holds the reference to 
 * the Script Engines.  UI calls this as do individual buttons.
 * @author Neil Ernst, Chris Callendar
 */
public class ScriptingBean {

	private ScriptingConstants scriptingConstants;
	private DefaultMainViewScriptingBean svsb;
	private BSFManager manager;
	private String language;
	
	public ScriptingBean(ShrimpProject project) {
		language = "javascript";
		
		scriptingConstants = new ScriptingConstants();
		svsb = new DefaultMainViewScriptingBean(project);

		try {
            manager = new BSFManager();
            manager.registerBean("mainViewScriptingBean", svsb);
            manager.registerBean("scriptingConstants", scriptingConstants);
            // for legacy scripts
            manager.registerBean("shrimpConstants", scriptingConstants);
        } catch (ExceptionInInitializerError e) { //thrown when shrimp is an applet
            //e.printStackTrace();
        } catch (NoClassDefFoundError e) { //thrown second constructor called from applet
            // do nothing
        }
	}
	
	/**
	 * return reference to the SV scripting bean,
	 * home of the actions.  Called from ShrimpView
	 * (where most adapters are hosted).
	 */
	public DefaultMainViewScriptingBean getShrimpViewScriptingBean() {
		return svsb;
	}

	public void runScriptFile(File scriptFile) throws FileNotFoundException, IOException, BSFException {
		runScriptFile(scriptFile.getName());
	}

	/**
	 * allows others to call this object with a filename to run
	 */
	public void runScriptFile(String fileName) throws FileNotFoundException, IOException, BSFException {
		// convert this file into a big string
		BufferedReader reader = new BufferedReader(new FileReader (fileName));
		StringBuffer allLines = new StringBuffer();
		String line = null;
		do {
			line = reader.readLine();
			if (line != null) {
				allLines.append(line + "\n");
			}
		} while (line != null);
		String language = BSFManager.getLangFromFilename(fileName);
		runScriptString(allLines.toString(), language);						
	}
	
	public void runScriptString(String scriptAsString) throws BSFException {
		runScriptString(scriptAsString, getLanguage());
	}
    
	public void runScriptString(String scriptAsString, String language) throws BSFException {
		manager.exec(language, "", 1, 1, scriptAsString);
	}
	
	/**
	 * @return The language the bean is using.
	 */
	public String getLanguage() {
		return language;
	}

	/**
	 * @param string
	 */
	public void setLanguage(String string) {
		language = string;
	}

}